atomate.utils.tests package — atomate 0.3 documentation

# atomate.utils.tests package

## Submodules

## atomate.utils.tests.test_loaders module

class `atomate.utils.tests.test_loaders.` `FuncTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()
  `test_get_wf_from_spec_dict`()
  `test_multi_parent`()

## atomate.utils.tests.test_utils module

class `atomate.utils.tests.test_utils.` `Task1`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  `run_task`(fw_spec)

class `atomate.utils.tests.test_utils.` `Task2`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  `run_task`(fw_spec)

class `atomate.utils.tests.test_utils.` `UtilsTests`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUp`()
  `test_append_fw`()
  `test_env_chk`()
  `test_get_mongolike`()
  `test_remove_fw`()

## Module contents